@@ -2,14 +2,43 @@ package Mac::FSEvents;
 
 use 5.008008;
 use strict;
+use base 'Exporter';
 
 use Mac::FSEvents::Event;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
+
+our @EXPORT_OK   = qw(NONE WATCH_ROOT);
+our %EXPORT_TAGS = ( flags => \@EXPORT_OK );
+
+my @maybe_export_ok = qw(IGNORE_SELF FILE_EVENTS);
 
 require XSLoader;
 XSLoader::load('Mac::FSEvents', $VERSION);
 
+# generate subs for each constant
+foreach my $constant ( @EXPORT_OK ) {
+    my ( undef, $value ) = constant($constant);
+
+    no strict 'refs';
+    *$constant = sub {
+        return $value;
+    };
+}
+
+# check that these flags are defined
+foreach my $constant ( @maybe_export_ok ) {
+    my ( undef, $value ) = constant($constant);
+
+    if ( defined($value) ) {
+        no strict 'refs';
+        *$constant = sub {
+            return $value;
+        };
+        push @EXPORT_OK, $constant;
+    }
+}
+
 sub DESTROY {
     my $self = shift;
     
@@ -30,11 +59,13 @@ Mac::FSEvents - Monitor a directory structure for changes
 =head1 SYNOPSIS
 
   use Mac::FSEvents;
+  # or use Mac::FSEvents qw(:flags);
 
   my $fs = Mac::FSEvents->new( {
       path    => '/',       # required, the path to watch
       latency => 2.0,       # optional, time to delay before returning events
       since   => 451349510, # optional, return events from this eventId
+      flags   => NONE,      # optional, set stream creation flags
   } );
 
   my $fh = $fs->watch;
@@ -94,6 +125,28 @@ Optional.  A previously obtained event ID may be passed as the since argument.
 notification will be sent for every event that has happened since that ID.  This can
 be useful for seeing what has changed while your program was not running.
 
+=item flags
+
+Optional.  Sets the flags provided to L<FSEventStreamCreate>.  In order to
+import the flag constants, you must provide C<:flags> to C<use Mac::FSEvents>.
+The following flags are supported:
+
+=over 8
+
+=item NONE
+
+=item WATCH_ROOT
+
+=item IGNORE_SELF (Only available on OS X 10.6 or greater)
+
+=item FILE_EVENTS (Only available on OS X 10.7 or greater)
+
+=back
+
+Consult the FSEvents documentation for what these flags do.
+
+Default: NONE
+
 =back
 
 =item B<watch>
